import { ResourceProps } from 'aws-cdk-lib';
import { DefaultInstanceTenancy, GatewayVpcEndpointOptions, SubnetSelection, VpnConnectionOptions } from 'aws-cdk-lib/aws-ec2';
import { IConstruct } from 'constructs';
import { FlowLogOptions, FourTierNetwork, IpAddressManager } from '.';
import { FourTierNetworkSpoke } from './four-tier-network-spoke';
import { IIpamPool, ITransitGatewayRouteTable, TransitGatewayProps } from '../ec2';
import { IIpv4CidrAssignment } from '../ec2/lib/cidr-assignment';
import { ITransitGateway } from '../ec2/transit-gateway';
import { GlobalNetwork } from '../networkmanager/global-network';
import { ISharedPrincipal } from '../ram';
export interface FourTierNetworkShareProperties {
    readonly autoAddAccounts?: boolean;
    readonly allowExternalPrincipals?: boolean;
    readonly pricipals?: ISharedPrincipal[];
}
export interface AddSpokeNetworkProps {
    readonly availabilityZones?: string[];
    readonly cidr?: IIpv4CidrAssignment;
    readonly defaultInstanceTenancy?: DefaultInstanceTenancy;
    readonly enableDnsHostnames?: boolean;
    readonly enableDnsSupport?: boolean;
    readonly flowLogs?: {
        [id: string]: FlowLogOptions;
    };
    readonly gatewayEndpoints?: {
        [id: string]: GatewayVpcEndpointOptions;
    };
    readonly maxAzs?: number;
    readonly vpcName?: string;
    readonly vpnConnections?: {
        [id: string]: VpnConnectionOptions;
    };
    readonly vpnGateway?: boolean;
    readonly vpnGatewayAsn?: number;
    readonly vpnRoutePropagation?: SubnetSelection[];
}
export interface FourTierNetworkHubProps extends ResourceProps {
    readonly addressManager?: IpAddressManager;
    readonly availabilityZones?: string[];
    readonly cidr?: IIpv4CidrAssignment;
    readonly clientVpnPool?: IIpamPool;
    readonly defaultInstanceTenancy?: DefaultInstanceTenancy;
    readonly defaultTransitGatewayRouteTable?: ITransitGatewayRouteTable;
    readonly enableDnsHostnames?: boolean;
    readonly enableDnsSupport?: boolean;
    readonly flowLogs?: {
        [id: string]: FlowLogOptions;
    };
    readonly gatewayEndpoints?: {
        [id: string]: GatewayVpcEndpointOptions;
    };
    readonly globalNetwork?: GlobalNetwork;
    readonly maxAzs?: number;
    readonly sharing?: FourTierNetworkShareProperties;
    readonly vpcName?: string;
    readonly vpnConnections?: {
        [id: string]: VpnConnectionOptions;
    };
    readonly vpnGateway?: boolean;
    readonly vpnGatewayAsn?: number;
    readonly vpnRoutePropagation?: SubnetSelection[];
}
export declare class FourTierNetworkHub extends FourTierNetwork {
    private readonly _flowLogConfiguration?;
    private readonly _sharedAccounts;
    private _resourceShare?;
    private _transitGateway?;
    readonly defaultTransitGatewayRouteTable?: ITransitGatewayRouteTable;
    readonly globalNetwork?: GlobalNetwork;
    readonly sharing: FourTierNetworkShareProperties;
    get transitGateway(): ITransitGateway | undefined;
    constructor(scope: IConstruct, id: string, props?: FourTierNetworkHubProps);
    private _addSharedAccount;
    private _ensureResourceShare;
    addSpoke(scope: IConstruct, id: string, props?: AddSpokeNetworkProps): FourTierNetworkSpoke;
    enableTransitGateway(props?: TransitGatewayProps): ITransitGateway;
}
